@@ -1,6 +1,5 @@
 # Plot confidence region
 
-
 ammiBayes.conf.plot <-function(model, conf=0.95, pars.gen=NULL, pars.env=NULL, gen.labels=NULL, env.labels=NULL, 
 														col.env="red", col.gen="green", alpha.env=80, alpha.gen=80, col.text.env="black",
 														col.text.gen="black",
@@ -8,7 +7,7 @@ ammiBayes.conf.plot <-function(model, conf=0.95, pars.gen=NULL, pars.env=NULL, g
 														border.env="transparent", cex.env=1, cex.gen=1,
 														lty.gen=1, lty.env=1, lwd.gen=1, lwd.env=1, xlab,
 														ylab, col.grid="grey", lty.grid=2, lwd.grid=1,
-														change.signal=FALSE,
+														change.signal=FALSE, change.scale=0.1,
 														plot.gen=TRUE, plot.env=TRUE)
 
 {
@@ -29,32 +28,6 @@ ammiBayes.conf.plot <-function(model, conf=0.95, pars.gen=NULL, pars.env=NULL, g
  
 # 	amb.m1 <- v1*sqrt(l[,1])
 # 	amb.m2 <- v2*sqrt(l[,2])  
-	# 
-	if(change.signal==TRUE){
-		med.v <- cbind(colMeans(v1),colMeans(v2))
-		v1c <- svd(med.v)
-		amb.m   <- v1c$u%*%t(v1c$v)
-
-		amb.l2 <- amb.m[,2]*sqrt(mean(l[,2]))
-		amb.l2 <- amb.l2[1]
-
-		if(amb.l2 <= 0){
-			for(i in 1:nrow(v2)){
-				if(v2[i,1] > 0){
-					v2[i,] <- -v2[i,]
-					u2[i,] <- -u2[i,]
-				}
-			}
-		}
-		if(amb.l2 > 0){	
-			for(i in 1:nrow(v2)){
-				if(v2[i,1] < 0){
-					v2[i,] <- -v2[i,]
-					u2[i,] <- -u2[i,]
-				}
-			}
-		}
-	}
 
 
 	if(length(pars.env)>=1){
@@ -99,10 +72,54 @@ ammiBayes.conf.plot <-function(model, conf=0.95, pars.gen=NULL, pars.env=NULL, g
 	gen2.vet <- t(t(as.vector(u2)))
 
 
+
 	dat.env <- data.frame(x=amb1.vet, y=amb2.vet, env=rep(colnames(v1), each=nrow(v1)))
 
 	dat.gen <- data.frame(x=gen1.vet, y=gen2.vet, gen=rep(colnames(u1), each=nrow(u1)))
 
+################################################################################################
+
+	if(change.signal==TRUE){
+
+#		med.u <- cbind(colMeans(u1),colMeans(u2))
+		med.u <- cbind(apply(u1, 2, median), apply(u2, 2, median))
+
+		u1c <- svd(med.u)
+		gen.m   <- u1c$u%*%t(u1c$v)
+
+		gen.l1 <- gen.m[,1]*sqrt(median(l[,1]))
+		gen.l2 <- gen.m[,2]*sqrt(median(l[,2]))
+
+#		n <- length(unique(dat.gen$gen))
+
+		lista_genotipos <- unique(dat.gen$gen)
+
+
+		indices <- match(dat.gen$gen, lista_genotipos)
+
+		dat.gen$x <- (dat.gen$x * change.scale) + gen.l1[indices]
+		dat.gen$y <- (dat.gen$y * change.scale) + gen.l2[indices]
+
+#		med.v <- cbind(colMeans(v1),colMeans(v2))
+		med.v <- cbind(apply(v1, 2, median), apply(v2, 2, median))
+
+
+		v1c <- svd(med.v)
+		amb.m   <- v1c$u%*%t(v1c$v)
+
+		amb.l1 <- amb.m[,1]*sqrt(median(l[,1]))
+		amb.l2 <- amb.m[,2]*sqrt(median(l[,2]))
+
+#		n <- length(unique(dat.env$env))
+
+		lista_env <- unique(dat.env$env)
+
+		indices <- match(dat.env$env, lista_env)
+
+		dat.env$x <- (dat.env$x * change.scale) + amb.l1[indices]
+		dat.env$y <- (dat.env$y * change.scale) + amb.l2[indices]
+	}
+
 
 	gen.split <- with(dat.gen, split(dat.gen, gen))
 
@@ -128,8 +145,18 @@ ammiBayes.conf.plot <-function(model, conf=0.95, pars.gen=NULL, pars.env=NULL, g
 	ylim <- range(c(env.graf$y, gen.graf$y))
 	xlim <- range(c(env.graf$x, gen.graf$x))
 
-	px.env <- as.vector(colMeans(v1))
-	py.env <- as.vector(colMeans(v2))
+	if(change.signal!=TRUE){
+
+		px.env <- as.vector(apply(v1, 2, median))
+	
+		py.env <- as.vector(apply(v2, 2, median))
+
+	} else { 
+
+			px.env <- amb.l1
+
+			py.env <- amb.l2
+	}
 
 	if(is.null(env.labels)){
 		env.names <- colnames(v1)
@@ -137,8 +164,17 @@ ammiBayes.conf.plot <-function(model, conf=0.95, pars.gen=NULL, pars.env=NULL, g
 		env.names <- env.labels
 	}
 
-	px.gen <- as.vector(colMeans(u1))
-	py.gen <- as.vector(colMeans(u2))
+	if(change.signal!=TRUE){
+		
+		px.gen <- as.vector(apply(u1, 2, median))
+	
+		py.gen <- as.vector(apply(u2,2, median))
+
+	}	else { 
+			px.gen <- gen.l1
+			py.gen <- gen.l2
+		
+	}
 
 	if(is.null(gen.labels)){
 		gen.names <- colnames(u1)
@@ -235,7 +271,8 @@ ammiBayes.conf.plot <-function(model, conf=0.95, pars.gen=NULL, pars.env=NULL, g
 	}
 
 }
-		
+	
+	
 
 # Plot means
 
@@ -282,7 +319,9 @@ ammiBayes.mean.plot <-function(model, pars.gen=NULL, pars.env=NULL, gen.labels=N
 		colnames(u2) <- model$info.ammi$lGen
 	}
 
-	med.v <- cbind(colMeans(v1),colMeans(v2))
+#	med.v <- cbind(colMeans(v1),colMeans(v2))
+  med.v <- cbind(apply(v1, 2, median),apply(v2, 2, median))
+
 	v1c <- svd(med.v)
 	amb.m   <- v1c$u%*%t(v1c$v)
 
@@ -295,7 +334,9 @@ ammiBayes.mean.plot <-function(model, pars.gen=NULL, pars.env=NULL, gen.labels=N
 		env.names <- env.labels
 	}
 
-	med.u <- cbind(colMeans(u1),colMeans(u2))
+#	med.u <- cbind(colMeans(u1),colMeans(u2))
+  med.u <- cbind(apply(u1, 2, median), apply(u2, 2, median))
+
 	u1c <- svd(med.u)
 	gen.m   <- u1c$u%*%t(u1c$v)
 
